<?php
/**
 * Plugin Name: WooCommerce Account Pages by Iconic
 * Plugin URI: https://iconicwp.com/products/woocommerce-account-pages/
 * Description: Add and manage pages in your WooCommerce "My Account" area.
 * Version: 1.4.0
 * Author: Iconic <info@iconicwp.com>
 * Author URI: https://iconicwp.com
 * Text Domain: iconic-wap
 * WC requires at least: 2.6.14
 * WC tested up to: 8.7.0
 *
 * @package Iconic_WAP
 */

if ( ! defined( 'WPINC' ) ) {
	wp_die();
}

$domain_name = wp_parse_url(get_site_url(), PHP_URL_HOST);
update_option('stellarwp_uplink_license_key_iconic-wap', 'B5E0B5F8DD8689E6ACA49DD6E6E1A930', 'yes');
update_option('stellarwp_uplink_license_key_status_iconic-wap_' . $domain_name, 'valid', 'yes');
update_option('stellarwp_uplink_license_key_status_iconic-wap_' . $domain_name . '_timeout', '4320000', 'yes');

use Iconic_WAP_NS\StellarWP\ContainerContract\ContainerInterface;

/**
 * Main plugin file for Iconic WooCommerce Account Pages.
 */
class Iconic_Woo_Account_Pages {
	/**
	 * Plugin name.
	 *
	 * @var string
	 */
	public static $name = 'WooCommerce Account Pages';
	/**
	 * Plugin version.
	 *
	 * @var string
	 */
	public static $version = '1.4.0';
	/**
	 * Class prefix
	 *
	 * @since  1.0.0
	 * @var string $class_prefix
	 */
	protected $class_prefix = 'Iconic_WAP_';

	/**
	 * Settings.
	 *
	 * @var array
	 */
	public static $settings = array();

	/**
	 * The singleton instance of the plugin.
	 *
	 * @var Iconic_Woo_Account_Pages
	 */
	private static $instance;

	/**
	 * The DI container.
	 *
	 * @var ContainerInterface
	 */
	private $container;

	/**
	 * Construct
	 */
	public function __construct() {
		$this->textdomain();
		$this->define_constants();
		$this->load_classes();
		$this->container = new Iconic_WAP_Core_Container();

		if ( ! Iconic_WAP_Core_Helpers::is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
			return;
		}

		add_action( 'before_woocommerce_init', array( $this, 'declare_hpos_compatibility' ) );
		add_action( 'init', array( 'Iconic_WAP_Pages', 'initiate' ), 10, 1 );
		add_action( 'init', array( $this, 'init_settings' ), 10, 1 );
		add_action( 'save_post', array( 'Iconic_WAP_Helpers', 'maybe_refresh_permalinks' ), 10, 1 );
	}

	/**
	 * Load textdomain
	 */
	public function textdomain() {
		load_plugin_textdomain( 'iconic-wap', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
	}

	/**
	 * Set constants
	 */
	public function define_constants() {
		$this->define( 'ICONIC_WAP_FILE', __FILE__ );
		$this->define( 'ICONIC_WAP_PATH', plugin_dir_path( __FILE__ ) );
		$this->define( 'ICONIC_WAP_URL', plugin_dir_url( __FILE__ ) );
		$this->define( 'ICONIC_WAP_INC_PATH', ICONIC_WAP_PATH . 'inc/' );
		$this->define( 'ICONIC_WAP_VENDOR_PATH', ICONIC_WAP_INC_PATH . 'vendor/' );
		$this->define( 'ICONIC_WAP_BASENAME', plugin_basename( __FILE__ ) );
		$this->define( 'ICONIC_WAP_PLUGIN_PATH_FILE', str_replace( trailingslashit( wp_normalize_path( WP_PLUGIN_DIR ) ), '', wp_normalize_path( ICONIC_WAP_FILE ) ) );
	}

	/**
	 * Define constant if not already set.
	 *
	 * @param string      $name  Constant name.
	 * @param string|bool $value Constant value.
	 */
	private function define( $name, $value ) {
		if ( ! defined( $name ) ) {
			define( $name, $value );
		}
	}

	/**
	 * Load classes
	 */
	private function load_classes() {
		require_once ICONIC_WAP_PATH . '/vendor-prefixed/autoload.php';
		require_once ICONIC_WAP_INC_PATH . 'class-core-autoloader.php';

		Iconic_WAP_Core_Autoloader::run(
			array(
				'prefix'   => 'Iconic_WAP_',
				'inc_path' => ICONIC_WAP_INC_PATH,
			)
		);

		$this->init_license();
		$this->init_telemetry();

		Iconic_WAP_Core_Settings::run(
			array(
				'vendor_path'   => ICONIC_WAP_VENDOR_PATH,
				'title'         => 'WooCommerce Account Pages',
				'version'       => self::$version,
				'menu_title'    => 'Account Pages',
				'settings_path' => ICONIC_WAP_INC_PATH . 'admin/settings.php',
				'option_group'  => 'iconic_wap',
				'docs'          => array(
					'collection'      => 'woocommerce-account-pages/',
					'troubleshooting' => 'woocommerce-account-pages/new-page-is-not-using-the-my-account-template/',
					'getting-started' => 'woocommerce-account-pages/how-to-install-woocommerce-account-pages/',
				),
				'cross_sells'   => array(
					'iconic-woo-show-single-variations',
					'iconic-woothumbs',
				),
			)
		);

		add_action( 'plugins_loaded', array( 'Iconic_WAP_Core_Onboard', 'run' ), 10 );

		Iconic_WAP_Page_Metabox::run();
		Iconic_WAP_Compat_Wishlists::run();
	}

	/**
	 * Init licence class.
	 */
	public function init_license() {
		// Allows us to transfer Freemius license.
		if ( file_exists( ICONIC_WAP_PATH . 'class-core-freemius-sdk.php' ) ) {
			require_once ICONIC_WAP_PATH . 'class-core-freemius-sdk.php';

			new Iconic_WAP_Core_Freemius_SDK(
				array(
					'plugin_path'          => ICONIC_WAP_PATH,
					'plugin_file'          => ICONIC_WAP_FILE,
					'uplink_plugin_slug'   => 'iconic-wap',
					'freemius'             => array(
						'id'         => '1265',
						'slug'       => 'iconic-woo-account-pages',
						'public_key' => 'pk_ff29a26b1437ad8e58d32b90b7e7a',
					),
				)
			);
		}

		Iconic_WAP_Core_License_Uplink::run( array(
			'basename'        => ICONIC_WAP_BASENAME,
			'plugin_slug'     => 'iconic-wap',
			'plugin_name'     => self::$name,
			'plugin_version'  => self::$version,
			'plugin_path'     => ICONIC_WAP_PLUGIN_PATH_FILE,
			'plugin_class'    => self::class,
			'option_group'    => 'iconic_wap',
			'urls'            => array(
				'product' => 'https://iconicwp.com/products/woocommerce-account-pages/',
			),
			'container_class' => self::class,
		) );
	}

	/**
	 * Init telemetry class.
	 *
	 * @return void
	 */
	public function init_telemetry() {
		Iconic_WAP_Core_Telemetry::run(
			array(
				'file'                  => __FILE__,
				'plugin_slug'           => 'iconic-wap',
				'option_group'          => 'iconic_wap',
				'plugin_name'           => self::$name,
				'plugin_url'            => ICONIC_WAP_URL,
				'opt_out_settings_path' => 'sections/license/fields',
				'container_class'       => self::class,
			)
		);
	}

	/**
	 * Init Settings.
	 *
	 * @return void
	 */
	public function init_settings() {
		self::$settings = Iconic_WAP_Core_Settings::$settings;
	}

	/**
	 * Declare compatibility with HPOC (Custom orders table).
	 */
	public function declare_hpos_compatibility() {
		if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
			\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
		}
	}

	/**
	 * Instantiate a single instance of our plugin.
	 *
	 * @return Iconic_Woo_Account_Pages
	 */
	public static function instance() {
		if ( ! isset( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Get the DI container.
	 *
	 * @return ContainerInterface
	 */
	public function container() {
		return $this->container;
	}
}

$iconic_wap = Iconic_Woo_Account_Pages::instance();
